==> vpp-0.7.1.zip: html/classvpp_1_1_physical_device.js <==
var classvpp_1_1_physical_device =
[
    [ "EFormatUsage", "classvpp_1_1_physical_device.html#a61105887992ad91a08ce554f5cd5c640", [
      [ "OPTIMAL_TILING", "classvpp_1_1_physical_device.html#a61105887992ad91a08ce554f5cd5c640af1b0c73b321e2a98b867555409f9603a", null ],
      [ "LINEAR_TILING", "classvpp_1_1_physical_device.html#a61105887992ad91a08ce554f5cd5c640ae204a02a40f25518456fa93ec5ab1cf9", null ],
      [ "BUFFER", "classvpp_1_1_physical_device.html#a61105887992ad91a08ce554f5cd5c640aef1ee44b62ee00fed1eb117c32b92404", null ]
    ] ],
    [ "PhysicalDevice", "classvpp_1_1_physical_device.html#adb776111ceffebe71814a3f2fd86fd19", null ],
    [ "PhysicalDevice", "classvpp_1_1_physical_device.html#a8b3cef6361d0f7f1fd301119a39cf235", null ],
    [ "getLimitValuesAsText", "classvpp_1_1_physical_device.html#ace2e8b964de7fed66fed08688aae3660", null ],
    [ "getMemoryProperties", "classvpp_1_1_physical_device.html#a083228a0400e68788fa413ac6f2083e2", null ],
    [ "getPhysicalDeviceProperties", "classvpp_1_1_physical_device.html#a0c1fef734409c39b7372d69bad9ace6d", null ],
    [ "getQueueFamilyProperties", "classvpp_1_1_physical_device.html#a31e80c5276ec6f1c8880d31cac4f39c0", null ],
    [ "handle", "classvpp_1_1_physical_device.html#a857fc1909d3f4e16d0ec93c1bbdf09d5", null ],
    [ "operator bool", "classvpp_1_1_physical_device.html#a2ab97412c5dd588ea608b105fad06d5c", null ],
    [ "queueFamilyCount", "classvpp_1_1_physical_device.html#aa18169e11073ae919b61ea4d20fa39da", null ],
    [ "supportsDepthStencilFormat", "classvpp_1_1_physical_device.html#a30e6c66cf00ee2926c70f73e123ab938", null ],
    [ "supportsFeature", "classvpp_1_1_physical_device.html#a512ca74d7a51417ec3baa6a47144c8fb", null ],
    [ "supportsFormat", "classvpp_1_1_physical_device.html#aab52b68315c5e9d70d27c08f257b5565", null ],
    [ "supportsSurface", "classvpp_1_1_physical_device.html#ac9bee39a013daba88abcfb00a83b2c2a", null ]
];

==> vpp-0.8.1.zip: html/classvpp_1_1_physical_device.js <==
var classvpp_1_1_physical_device =
[
    [ "EFormatUsage", "classvpp_1_1_physical_device.html#a61105887992ad91a08ce554f5cd5c640", [
      [ "OPTIMAL_TILING", "classvpp_1_1_physical_device.html#a61105887992ad91a08ce554f5cd5c640af1b0c73b321e2a98b867555409f9603a", null ],
      [ "LINEAR_TILING", "classvpp_1_1_physical_device.html#a61105887992ad91a08ce554f5cd5c640ae204a02a40f25518456fa93ec5ab1cf9", null ],
      [ "BUFFER", "classvpp_1_1_physical_device.html#a61105887992ad91a08ce554f5cd5c640aef1ee44b62ee00fed1eb117c32b92404", null ]
    ] ],
    [ "PhysicalDevice", "classvpp_1_1_physical_device.html#adb776111ceffebe71814a3f2fd86fd19", null ],
    [ "PhysicalDevice", "classvpp_1_1_physical_device.html#a8b3cef6361d0f7f1fd301119a39cf235", null ],
    [ "enumerateExtensions", "classvpp_1_1_physical_device.html#abb8cdf86c7b4324ce317127c6f5053b4", null ],
    [ "features", "classvpp_1_1_physical_device.html#aaa3e3036ff4f29374fac412ee5e855bf", null ],
    [ "getLimitValuesAsText", "classvpp_1_1_physical_device.html#ace2e8b964de7fed66fed08688aae3660", null ],
    [ "getMemoryProperties", "classvpp_1_1_physical_device.html#a083228a0400e68788fa413ac6f2083e2", null ],
    [ "getQueueFamilyProperties", "classvpp_1_1_physical_device.html#a31e80c5276ec6f1c8880d31cac4f39c0", null ],
    [ "handle", "classvpp_1_1_physical_device.html#a857fc1909d3f4e16d0ec93c1bbdf09d5", null ],
    [ "operator bool", "classvpp_1_1_physical_device.html#a2ab97412c5dd588ea608b105fad06d5c", null ],
    [ "properties", "classvpp_1_1_physical_device.html#aca0f59039a32919ce90ef089c0049567", null ],
    [ "queueFamilyCount", "classvpp_1_1_physical_device.html#aa18169e11073ae919b61ea4d20fa39da", null ],
    [ "supportsDepthStencilFormat", "classvpp_1_1_physical_device.html#a30e6c66cf00ee2926c70f73e123ab938", null ],
    [ "supportsFormat", "classvpp_1_1_physical_device.html#aab52b68315c5e9d70d27c08f257b5565", null ],
    [ "supportsSurface", "classvpp_1_1_physical_device.html#ac9bee39a013daba88abcfb00a83b2c2a", null ]
];
